<?php
class Magento1_FeedbackCompany_Block_Adminhtml_Config_Form extends Mage_Adminhtml_Block_Widget_Form
{
    /**
     * Prepare feedback company configuration form
     *
     * @return Mage_Adminhtml_Block_Widget_Form
     */
    protected function _prepareForm()
    {
        $configModel = Mage::getModel('magento1_feedbackcompany/options');
        $configModel->loadConfig();

        $form = new Varien_Data_Form(array(
            'id' => 'edit_form',
            'action' => $this->getUrl(
                '*/*/save',
                array(
                    '_current' => true
                )
            ),
            'method' => 'post'
        ));

        $accessFieldset = $form->addFieldset('access', array(
            'legend' => $this->__('Authentication Settings')
        ));

        $clientId = $configModel->getData('client_id') ? $configModel->getData('client_id') : '';
        $accessFieldset->addField(
            'client_id',
            'text',
            array(
                'label'     => $this->__('Client Id'),
                'class'     => 'required-entry',
                'required'  => true,
                'name'      => 'client_id',
                'value'     => $clientId,
                'note'      => $this->__('To get your client Id and Client Secret check the <a href="https://www.feedbackcompany.com/account">account page</a> of the Feedback Company portal')
            )
        );

        $clientSecret = $configModel->getData('client_secret') ? $configModel->getData('client_secret') : '';
        $accessFieldset->addField(
            'client_secret',
            'text',
            array(
                'label'     => $this->__('Client Secret'),
                'class'     => 'required-entry',
                'required'  => true,
                'name'      => 'client_secret',
                'value'     => $clientSecret
            )
        );

        $languageFieldset = $form->addFieldset('language_settings', array(
            'legend' => $this->__('Language Settings')
        ));

        $activeLanguage = $configModel->getData('active_language') ? $configModel->getData('active_language') : '';
        $localeOptions = Mage::app()->getLocale()->getOptionLocales();
        $locales = array();
        foreach (Mage::app()->getStores() as $store) {
            $localeCode = $store->getConfig('general/locale/code');
            $localeLabel = $localeCode;
            foreach ($localeOptions as $localeInfo) {
                if ($localeCode === $localeInfo["value"]) {
                    $localeLabel = $localeInfo["label"];
                }
            }
            $locales[$localeCode] = $localeLabel;
        }
        $languageFieldset->addField(
            'active_language',
            'select',
            array(
                'label'     => $this->__('Active language'),
                'class'     => 'required-entry',
                'required'  => true,
                'name'      => 'active_language',
                'values'    => array_merge(array('all' => 'All languages'), $locales),
                'value'     => $activeLanguage,
                'note'      => $this->__('If you select a language, the widget and order registration is only active for this language.')
            )
        );

        /** @var Mage_Sales_Model_Order_Config $orderConfigModel */
        $orderConfigModel = Mage::getModel('sales/order_config');
        $orderStatuses = array();
        foreach ($orderConfigModel->getStatuses() as $code => $label) {
            $orderStatuses[] = array(
                'label' => $this->__($label),
                'value' => $code
            );
        }

        $orderFieldset = $form->addFieldset('order_registration', array(
            'legend' => $this->__('Shop Settings')
        ));

        $orderTrigger = $configModel->getData('order_registration_trigger')
            ? $configModel->getData('order_registration_trigger') : '';
        $orderNote = 'Configure which order status should trigger a review '.
            'invitation and the delay before sending the review invitation and reminder.'.
            ' Also configure how to display the product reviews widget on the product page.';
        $orderFieldset->addField(
            'order_registration_trigger',
            'select',
            array(
                'label'       => $this->__('Order Registration Status'),
                'class'       => 'required-entry',
                'required'    => true,
                'name'        => 'order_registration_trigger',
                'values'      => array_merge(array('' => ''), $orderStatuses),
                'value'       => $orderTrigger,
                'note'        => $this->__($orderNote)
            )
        );

        $reviewInvitationPeriod = $configModel->getData('review_invitation_delay_period')
            ? $configModel->getData('review_invitation_delay_period') : 'Days';

        $reviewDelayPeriodNote = 'Here you can set the delay when the invitation will be sent. ' .
            'Choose between minutes, hours, days or weekdays. ' .
            'When weekdays is selected invitations will not be sent on saturday and sunday.';
        $orderFieldset->addField(
            'review_invitation_delay_period',
            'select',
            array(
                'label'     => $this->__('Invitation delay period'),
                'name'      => 'review_invitation_delay_period',
                'values'    => $configModel->getReviewDelayPeriodOptions(),
                'value'     => $reviewInvitationPeriod,
                'note'      => $this->__($reviewDelayPeriodNote)
            )
        );

        $reviewInvitationDelay = $configModel->getData('review_invitation_delay_amount') >= 0
            ? $configModel->getData('review_invitation_delay_amount') : '7';
        $orderFieldset->addField(
            'review_invitation_delay_amount',
            'text',
            array(
                'label'     => $this->__('Invitation delay amount'),
                'name'      => 'review_invitation_delay_amount',
                'class'     => 'validate-digits',
                'value'     => $reviewInvitationDelay
            )
        );

        $reviewInvitationReminderPeriod = $configModel->getData('review_invitation_reminder_delay_period')
            ? $configModel->getData('review_invitation_reminder_delay_period') : 'Days';
        $orderFieldset->addField(
            'review_invitation_reminder_delay_period',
            'select',
            array(
                'label'     => $this->__('Reminder delay period'),
                'name'      => 'review_invitation_reminder_delay_period',
                'values'    => $configModel->getReviewDelayPeriodOptions(),
                'value'     => $reviewInvitationReminderPeriod,
                'note'      => $this->__('Here you can set the delay of the reminder invitation.')
            )
        );

        $reviewInvitationReminderDelay = $configModel->getData('review_invitation_reminder_delay_amount') >= 0
            ? $configModel->getData('review_invitation_reminder_delay_amount') : '14';
        $orderFieldset->addField(
            'review_invitation_reminder_delay_amount',
            'text',
            array(
                'label'     => $this->__('Reminder delay amount'),
                'name'      => 'review_invitation_reminder_delay_amount',
                'class'     => 'validate-digits',
                'value'     => $reviewInvitationReminderDelay
            )
        );

        $merchantReviewsFieldset = $form->addFieldset('merchant_reviews_widget', array(
            'legend' => $this->__('Merchant reviews widget')
        ));

        $merchantReviewsSize = $configModel->getData('merchant_reviews_widget_size')
            ? $configModel->getData('merchant_reviews_widget_size') : 'small';
        $merchantReviewsFieldset->addField(
            'merchant_reviews_widget_size',
            'select',
            array(
                'label'     => $this->__('Size'),
                'name'      => 'merchant_reviews_widget_size',
                'values'    => $configModel->getMerchantReviewsWidgetSizeOptions(),
                'value'     => $merchantReviewsSize
            )
        );

        $merchantReviewsAmount = $configModel->getData('merchant_reviews_widget_amount_of_reviews')
            ? $configModel->getData('merchant_reviews_widget_amount_of_reviews') : '0';
        $merchantReviewsFieldset->addField(
            'merchant_reviews_widget_amount_of_reviews',
            'select',
            array(
                'label'     => $this->__('Amount of reviews'),
                'name'      => 'merchant_reviews_widget_amount_of_reviews',
                'values'    => $configModel->getMerchantReviewsWidgetAmountOfReviewsOptions(),
                'value'     => $merchantReviewsAmount
            )
        );

        $productReviewsExtendedDisplay = $configModel->getData('product_reviews_widget_extended_display_type')
            ? $configModel->getData('product_reviews_widget_extended_display_type') : 'sidebar';
        $orderFieldset->addField(
            'product_reviews_widget_extended_display_type',
            'select',
            array(
                'label'     => $this->__('Product page widget'),
                'name'      => 'product_reviews_widget_extended_display_type',
                'values'    => array(
                    'sidebar' => $this->__('Sidebar'),
                    'popup'   => $this->__('Popup'),
                    'inline'  => $this->__('Inline')
                ),
                'value'      => $productReviewsExtendedDisplay
            )
        );

        $previewFieldset = $form->addFieldset('widget_preview', array(
            'legend' => $this->__('Widget previews')
        ));

        $previewFieldset->addType('merchant_preview', 'Magento1_FeedbackCompany_Block_Adminhtml_Config_Renderer_MerchantPreview');

        $previewFieldset->addField('merchant_widget_preview', 'merchant_preview', array(
            'name'      => 'merchant_widget_preview',
            'label'     => $this->__('Merchant reviews widget preview'),
        ));

        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }
}
