<?php
class Magento1_FeedbackCompany_Adminhtml_Feedbackcompany_IndexController
    extends Mage_Adminhtml_Controller_Action
{
    /**
     * Feedback company configuration form.
     *
     * @return void
     * @throws Exception
     */
    public function indexAction()
    {
        $this->loadLayout();

        $this->_addBreadcrumb(
            Mage::helper('magento1_feedbackcompany')->__('Feedback company configuration'),
            Mage::helper('magento1_feedbackcompany')->__('Feedback company configuration')
        );

        $this->renderLayout();
    }

    /**
     * Save feedback company configuration process.
     *
     * @return void
     * @throws Exception
     */
    public function saveAction()
    {
        if (!$this->getRequest()->isPost()) {
            $this->_getSession()->addError($this->__('Specified invalid data.'));
            $this->_redirect('*/*/');
            return;
        }

        $config = $this->getRequest()->getPost();
        if (!$this->_validateConfig($config)) {
            $this->_redirect('*/*/');
            return;
        }

        try {
            $configModel = Mage::getModel('magento1_feedbackcompany/options');
            $configModel->loadConfig();

            $configModel->addData($config);

            $currentCredentials = array(
                'client_id'     => $configModel->getData('client_id'),
                'client_secret' => $configModel->getData('client_secret')
            );

            $receivedCredentials = array(
                'client_id'     => $config['client_id'],
                'client_secret' => $config['client_secret']
            );

            $idDoesntExist = !$configModel->getId();
            $credentialsChanged = $currentCredentials !== $receivedCredentials;

            $requireNewAccessToken = $credentialsChanged || $idDoesntExist;
            if (requireNewAccessToken) {
                $accessTokenCall = $configModel->getNewAccessToken();
                if (is_array($accessTokenCall)) {
                    $this->_getSession()->addError($accessTokenCall['error']);
                }
            }

            $accessToken = $configModel->getData('access_token');
        

            if (isset($accessToken)) {
                $errors = $configModel->registerWidgets();
                if (count($errors) > 0) {
                    foreach (array_unique($errors) as $error) {
                        $this->_getSession()->addError($error);
                    }
                }
            }

            $configModel->save();

            $this->_getSession()->addSuccess(
                $this->__(
                    'The feedback company configuration was successfully saved.'
                )
            );
        } catch (Exception $e) {
            $this->_getSession()->addError($e->getMessage());
        }

        $this->_redirect('*/*/');
    }

    /**
     * Validate configuration form
     *
     * @param array $params
     * @return boolean
     */
    protected function _validateConfig($params)
    {
        if (!isset($params['client_id']) && !isset($params['client_secret'])) {
            $this->_getSession()->addError($this->__('The combination of client id and client secret is invalid.'));
            return false;
        }

        if (!is_int($params['review_invitation_delay_amount'])
            && (int) $params['review_invitation_delay_amount'] < 0) {
            $this->_getSession()->addError($this->__('The review invitation delay amount is invalid.'));
            return false;
        }

        if (!is_int($params['review_invitation_reminder_delay_amount'])
            && (int) $params['review_invitation_reminder_delay_amount'] < 0) {
            $this->_getSession()->addError($this->__('The review invitation reminder delay amount is invalid.'));
            return false;
        }

        if ($params['review_invitation_delay_period'] == 'weekdays'
                && $params['review_invitation_reminder_delay_period'] <> 'weekdays') {
            $this->_getSession()->addError($this->__('The Reminder delay period must be a weekdays.'));
            return false;
        }

        if ($params['review_invitation_reminder_delay_period'] == 'weekdays'
                && $params['review_invitation_delay_period'] <> 'weekdays') {
            $this->_getSession()->addError($this->__('The invitation delay period must be a weekdays.'));
            return false;
        }

        return true;
    }

    /**
     * Check admin permissions for this controller
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        /** @var $session Mage_Admin_Model_Session */
        $session = Mage::getSingleton('admin/session');

        return $session->isAllowed('admin/feedbackcompany');
    }
}
